[GRASS-SVN] r60289 - grass/trunk/lib/gis

svn_grass at osgeo.org svn_grass at osgeo.org
Sat May 17 10:18:19 PDT 2014


Author: glynn
Date: 2014-05-17 10:18:19 -0700 (Sat, 17 May 2014)
New Revision: 60289

Modified:
   grass/trunk/lib/gis/error.c
Log:
Replace SIGSEGV-on-error with SIGABRT-on-error


Modified: grass/trunk/lib/gis/error.c
===================================================================
--- grass/trunk/lib/gis/error.c	2014-05-17 16:59:50 UTC (rev 60288)
+++ grass/trunk/lib/gis/error.c	2014-05-17 17:18:19 UTC (rev 60289)
@@ -17,7 +17,6 @@
 #include <unistd.h>
 #include <time.h>
 #include <stdarg.h>
-#include <signal.h>
 #include <sys/types.h>
 #include <grass/glocale.h>
 #include <grass/gis.h>
@@ -161,12 +160,12 @@
 
     G__call_error_handlers();
 
     /* Raise SIGSEGV, useful for debugging only.
      * Type "export GRASS_SIGSEGV_ON_ERROR=1"
      * to enable this feature using bash.
      */
-    if (getenv("GRASS_SIGSEGV_ON_ERROR"))
-        raise(SIGSEGV);
+    if (getenv("GRASS_ABORT_ON_ERROR"))
+        abort();
 
     exit(EXIT_FAILURE);
 }
@@ -161,12 +160,12 @@
     G__call_error_handlers();
 
-    /* Raise SIGSEGV, useful for debugging only.
-     * Type "export GRASS_SIGSEGV_ON_ERROR=1"
+    /* Raise SIGABRT, useful for debugging only.
+     * Type "export GRASS_ABORT_ON_ERROR=1"
      * to enable this feature using bash.
      */



More information about the grass-commit mailing list